make_edge_between

Function make_edge_between 

pub fn make_edge_between(
    model: &mut Model,
    curve: Curve,
    range: (f64, f64),
    from: &Shape,
    to: &Shape,
    tol: Tolerances,
) -> OgeomResult<Built>
Build an edge between two existing vertices, on curve.

Errors

OgeomError::Construction if either shape is not a vertex, or the curve’s ends do not reach them within tolerance.