pub struct MeshSolid {
pub shape: Shape,
pub closed: bool,
pub report: MeshSolidReport,
}Expand description
The result of solid_from_mesh.
Fields
shape: ShapeA solid when the mesh closes (a compound of solids when it is several disjoint closed pieces), and otherwise a shell, or a compound of shells.
closed: boolWhether every piece closed and became a solid.
report: MeshSolidReportWhat was built, and where the mesh does not close.