make_box

Function make_box 

pub fn make_box(
    model: &mut Model,
    frame: Frame,
    size: (f64, f64, f64),
    tol: Tolerances,
) -> OgeomResult<Built>
Build an axis-aligned box in frame, spanning size along each of its axes from the frame’s origin.

Errors

OgeomError::Construction if any dimension is not finite and positive.