pub struct ClosestPair {
pub point_a: Point,
pub point_b: Point,
pub support_a: Shape,
pub support_b: Shape,
}Expand description
One pair of nearest points, with the elements they lie on.
Fields
point_a: PointThe nearest point on the first shape.
point_b: PointThe nearest point on the second.
support_a: ShapeThe vertex, edge or face of the first shape the point lies on.
support_b: ShapeThe same for the second shape.