pub struct ShapeDistance {
pub distance: f64,
pub pairs: Vec<ClosestPair>,
}Expand description
The minimum distance between two shapes, with everywhere it is attained.
Fields
distance: f64The distance.
pairs: Vec<ClosestPair>Every pair of nearest points found within tolerance of the minimum. Parallel walls meet at a representative pair, not at every point of the overlap.