pub fn make_wire(
model: &mut Model,
edges: &[Shape],
tol: Tolerances,
) -> OgeomResult<Built>Expand description
Build a wire from edges that meet end to end.
Errors
OgeomError::Construction if a child is not
an edge, the list is empty, or consecutive edges do not share a vertex.